==> haskell-aws-0.22-60-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aws.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aws
version:              0.22
visibility:           public
id:                   aws-0.22-70wrAGm2QRzJyxcIoZiVt4
key:                  aws-0.22-70wrAGm2QRzJyxcIoZiVt4
license:              BSD-3-Clause
copyright:            See contributors list in README and LICENSE file
maintainer:           aristidb@gmail.com
author:               Aristid Breitkreuz, contributors see README
homepage:             http://github.com/aristidb/aws
synopsis:             Amazon Web Services (AWS) for Haskell
description:
    Bindings for Amazon Web Services (AWS), with the aim of supporting all AWS services. To see a high level overview of the library, see the README at <https://github.com/aristidb/aws/blob/master/README.md>.

category:             Network, Web, AWS, Cloud, Distributed Computing
abi:                  944724a5727e959ec8b4da7f38eff030
exposed:              True
exposed-modules:
    Aws Aws.Aws Aws.Core Aws.DynamoDb Aws.DynamoDb.Commands
    Aws.DynamoDb.Commands.BatchGetItem
    Aws.DynamoDb.Commands.BatchWriteItem
    Aws.DynamoDb.Commands.DeleteItem Aws.DynamoDb.Commands.GetItem
    Aws.DynamoDb.Commands.PutItem Aws.DynamoDb.Commands.Query
    Aws.DynamoDb.Commands.Scan Aws.DynamoDb.Commands.Table
    Aws.DynamoDb.Commands.UpdateItem Aws.DynamoDb.Core
    Aws.Ec2.InstanceMetadata Aws.Iam Aws.Iam.Commands
    Aws.Iam.Commands.AddUserToGroup Aws.Iam.Commands.CreateAccessKey
    Aws.Iam.Commands.CreateGroup Aws.Iam.Commands.CreateUser
    Aws.Iam.Commands.DeleteAccessKey Aws.Iam.Commands.DeleteGroup
    Aws.Iam.Commands.DeleteGroupPolicy Aws.Iam.Commands.DeleteUser
    Aws.Iam.Commands.DeleteUserPolicy Aws.Iam.Commands.GetGroupPolicy
    Aws.Iam.Commands.GetUser Aws.Iam.Commands.GetUserPolicy
    Aws.Iam.Commands.ListAccessKeys Aws.Iam.Commands.ListGroupPolicies
    Aws.Iam.Commands.ListGroups Aws.Iam.Commands.ListMfaDevices
    Aws.Iam.Commands.ListUserPolicies Aws.Iam.Commands.ListUsers
    Aws.Iam.Commands.PutGroupPolicy Aws.Iam.Commands.PutUserPolicy
    Aws.Iam.Commands.RemoveUserFromGroup
    Aws.Iam.Commands.UpdateAccessKey Aws.Iam.Commands.UpdateGroup
    Aws.Iam.Commands.UpdateUser Aws.Iam.Core Aws.Iam.Internal
    Aws.Network Aws.S3 Aws.S3.Commands Aws.S3.Commands.CopyObject
    Aws.S3.Commands.DeleteBucket Aws.S3.Commands.DeleteObject
    Aws.S3.Commands.DeleteObjectVersion Aws.S3.Commands.DeleteObjects
    Aws.S3.Commands.GetBucket Aws.S3.Commands.GetBucketLocation
    Aws.S3.Commands.GetBucketObjectVersions Aws.S3.Commands.GetObject
    Aws.S3.Commands.GetService Aws.S3.Commands.HeadObject
    Aws.S3.Commands.Multipart Aws.S3.Commands.PutBucket
    Aws.S3.Commands.PutBucketVersioning Aws.S3.Commands.PutObject
    Aws.S3.Core Aws.Ses Aws.Ses.Commands
    Aws.Ses.Commands.DeleteIdentity
    Aws.Ses.Commands.GetIdentityDkimAttributes
    Aws.Ses.Commands.GetIdentityNotificationAttributes
    Aws.Ses.Commands.GetIdentityVerificationAttributes
    Aws.Ses.Commands.ListIdentities Aws.Ses.Commands.SendRawEmail
    Aws.Ses.Commands.SetIdentityDkimEnabled
    Aws.Ses.Commands.SetIdentityFeedbackForwardingEnabled
    Aws.Ses.Commands.SetIdentityNotificationTopic
    Aws.Ses.Commands.VerifyDomainDkim
    Aws.Ses.Commands.VerifyDomainIdentity
    Aws.Ses.Commands.VerifyEmailIdentity Aws.Ses.Core Aws.SimpleDb
    Aws.SimpleDb.Commands Aws.SimpleDb.Commands.Attributes
    Aws.SimpleDb.Commands.Domain Aws.SimpleDb.Commands.Select
    Aws.SimpleDb.Core Aws.Sqs Aws.Sqs.Commands Aws.Sqs.Commands.Message
    Aws.Sqs.Commands.Permission Aws.Sqs.Commands.Queue
    Aws.Sqs.Commands.QueueAttributes Aws.Sqs.Core

import-dirs:          /usr/lib/ghc-8.10.1/site-local/aws-0.22
library-dirs:         /usr/lib/ghc-8.10.1/site-local/aws-0.22
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/aws-0.22
hs-libraries:         HSaws-0.22-70wrAGm2QRzJyxcIoZiVt4
depends:
    aeson-1.5.1.0-9flD70y9OJL8EnSIjIcu4t
    attoparsec-0.13.2.4-75xefPYAxam1Yt9FZGmunF base-4.14.0.0
    base16-bytestring-0.1.1.6-DS9xLNC5hoWBUNdBXU0AGB
    base64-bytestring-1.1.0.0-4PKusBulJKl5JuJVlDvtDW
    blaze-builder-0.4.1.0-2R9yQhqQRKlArR2rpVisZG
    byteable-0.1.1-EIsD8YjxajzGjEMLynBvyB bytestring-0.10.10.0
    case-insensitive-1.2.1.0-4tL4tqWLN4BHWNmCD2HpmE
    cereal-0.5.8.1-HU1Om29vBJGHr3TJypdaoY
    conduit-1.3.2-6ZG6T5I5cKQFFD9qyOIpu
    conduit-extra-1.3.5-EeNOQtdUW6E7bNOkpWlcKM containers-0.6.2.1
    cryptonite-0.26-JIZdcaiOiQ0E7oAZnbqxMe
    data-default-0.7.1.1-9j14EdJuVkFLjYlD1tloIt directory-1.3.6.0
    exceptions-0.10.4 filepath-1.4.2.1
    http-client-tls-0.3.5.3-9aIlECza7ZkFTpV0gr5mQD
    http-conduit-2.3.7.3-9vdwb3fJwMNHg3c3AaWDDF
    http-types-0.12.3-4xQpZ1dm4sVLlP974qcom6
    lifted-base-0.2.3.12-32Je5waQHZkEwMmV5pIAvq
    memory-0.15.0-EuehB4FMe9b5ts9dSjTFQ5
    monad-control-1.0.2.3-Zolpha2nzyCWjP4MLl5a6 mtl-2.2.2
    network-3.1.1.1-CK9iofx0d8BBZLerEfDW1e
    network-bsd-2.8.1.0-9VdQYYkiaFR7vrQXuQSXuG
    old-locale-1.0.0.7-He1fhgasqBf2zFT9zlaLle
    resourcet-1.2.4.1-BfFxYNA42v4HhhW9DWi0Jk
    safe-0.3.19-CK0lfIX5mWD7fu30IXX07t
    scientific-0.3.6.2-KV9qEzQmSjuErx2uTg1kor
    tagged-0.8.6-6GC8EUw1ctH7ZAzzvpqZ7j text-1.2.3.2 time-1.9.3
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-BkkEehzCtfP8BROI0EUhVc
    utf8-string-1.0.1.1-L5P9SR8YxIu1NqwMrJwV7a
    vector-0.12.1.2-2820kU4E8Rq2FpOG9Xf2aE
    xml-conduit-1.9.0.0-3lzU4uGUZ6LIn8lU1AwHAc

haddock-interfaces:   /usr/share/doc/haskell-aws/html/aws.haddock
haddock-html:         /usr/share/doc/haskell-aws/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aws-0.22-69-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aws.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aws
version:              0.22
visibility:           public
id:                   aws-0.22-AIvPA3mBCXlG4NPpunWltA
key:                  aws-0.22-AIvPA3mBCXlG4NPpunWltA
license:              BSD-3-Clause
copyright:            See contributors list in README and LICENSE file
maintainer:           aristidb@gmail.com
author:               Aristid Breitkreuz, contributors see README
homepage:             http://github.com/aristidb/aws
synopsis:             Amazon Web Services (AWS) for Haskell
description:
    Bindings for Amazon Web Services (AWS), with the aim of supporting all AWS services. To see a high level overview of the library, see the README at <https://github.com/aristidb/aws/blob/master/README.md>.

category:             Network, Web, AWS, Cloud, Distributed Computing
abi:                  f0d15f99883783a9414d5a0739c30901
exposed:              True
exposed-modules:
    Aws Aws.Aws Aws.Core Aws.DynamoDb Aws.DynamoDb.Commands
    Aws.DynamoDb.Commands.BatchGetItem
    Aws.DynamoDb.Commands.BatchWriteItem
    Aws.DynamoDb.Commands.DeleteItem Aws.DynamoDb.Commands.GetItem
    Aws.DynamoDb.Commands.PutItem Aws.DynamoDb.Commands.Query
    Aws.DynamoDb.Commands.Scan Aws.DynamoDb.Commands.Table
    Aws.DynamoDb.Commands.UpdateItem Aws.DynamoDb.Core
    Aws.Ec2.InstanceMetadata Aws.Iam Aws.Iam.Commands
    Aws.Iam.Commands.AddUserToGroup Aws.Iam.Commands.CreateAccessKey
    Aws.Iam.Commands.CreateGroup Aws.Iam.Commands.CreateUser
    Aws.Iam.Commands.DeleteAccessKey Aws.Iam.Commands.DeleteGroup
    Aws.Iam.Commands.DeleteGroupPolicy Aws.Iam.Commands.DeleteUser
    Aws.Iam.Commands.DeleteUserPolicy Aws.Iam.Commands.GetGroupPolicy
    Aws.Iam.Commands.GetUser Aws.Iam.Commands.GetUserPolicy
    Aws.Iam.Commands.ListAccessKeys Aws.Iam.Commands.ListGroupPolicies
    Aws.Iam.Commands.ListGroups Aws.Iam.Commands.ListMfaDevices
    Aws.Iam.Commands.ListUserPolicies Aws.Iam.Commands.ListUsers
    Aws.Iam.Commands.PutGroupPolicy Aws.Iam.Commands.PutUserPolicy
    Aws.Iam.Commands.RemoveUserFromGroup
    Aws.Iam.Commands.UpdateAccessKey Aws.Iam.Commands.UpdateGroup
    Aws.Iam.Commands.UpdateUser Aws.Iam.Core Aws.Iam.Internal
    Aws.Network Aws.S3 Aws.S3.Commands Aws.S3.Commands.CopyObject
    Aws.S3.Commands.DeleteBucket Aws.S3.Commands.DeleteObject
    Aws.S3.Commands.DeleteObjectVersion Aws.S3.Commands.DeleteObjects
    Aws.S3.Commands.GetBucket Aws.S3.Commands.GetBucketLocation
    Aws.S3.Commands.GetBucketObjectVersions Aws.S3.Commands.GetObject
    Aws.S3.Commands.GetService Aws.S3.Commands.HeadObject
    Aws.S3.Commands.Multipart Aws.S3.Commands.PutBucket
    Aws.S3.Commands.PutBucketVersioning Aws.S3.Commands.PutObject
    Aws.S3.Core Aws.Ses Aws.Ses.Commands
    Aws.Ses.Commands.DeleteIdentity
    Aws.Ses.Commands.GetIdentityDkimAttributes
    Aws.Ses.Commands.GetIdentityNotificationAttributes
    Aws.Ses.Commands.GetIdentityVerificationAttributes
    Aws.Ses.Commands.ListIdentities Aws.Ses.Commands.SendRawEmail
    Aws.Ses.Commands.SetIdentityDkimEnabled
    Aws.Ses.Commands.SetIdentityFeedbackForwardingEnabled
    Aws.Ses.Commands.SetIdentityNotificationTopic
    Aws.Ses.Commands.VerifyDomainDkim
    Aws.Ses.Commands.VerifyDomainIdentity
    Aws.Ses.Commands.VerifyEmailIdentity Aws.Ses.Core Aws.SimpleDb
    Aws.SimpleDb.Commands Aws.SimpleDb.Commands.Attributes
    Aws.SimpleDb.Commands.Domain Aws.SimpleDb.Commands.Select
    Aws.SimpleDb.Core Aws.Sqs Aws.Sqs.Commands Aws.Sqs.Commands.Message
    Aws.Sqs.Commands.Permission Aws.Sqs.Commands.Queue
    Aws.Sqs.Commands.QueueAttributes Aws.Sqs.Core

import-dirs:          /usr/lib/ghc-8.10.1/site-local/aws-0.22
library-dirs:         /usr/lib/ghc-8.10.1/site-local/aws-0.22
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/aws-0.22
hs-libraries:         HSaws-0.22-AIvPA3mBCXlG4NPpunWltA
depends:
    aeson-1.5.2.0-9RTw8ryGp7WIZEOMbLe2St
    attoparsec-0.13.2.4-75xefPYAxam1Yt9FZGmunF base-4.14.0.0
    base16-bytestring-0.1.1.7-IF3oDT09hOj5uLqgHsC3Xr
    base64-bytestring-1.1.0.0-4PKusBulJKl5JuJVlDvtDW
    blaze-builder-0.4.1.0-2R9yQhqQRKlArR2rpVisZG
    byteable-0.1.1-EIsD8YjxajzGjEMLynBvyB bytestring-0.10.10.0
    case-insensitive-1.2.1.0-4tL4tqWLN4BHWNmCD2HpmE
    cereal-0.5.8.1-HU1Om29vBJGHr3TJypdaoY
    conduit-1.3.2-E73kZTPRwvcC4v4QmnYBd3
    conduit-extra-1.3.5-JbSefpLFWUqKgP8sdbsBOO containers-0.6.2.1
    cryptonite-0.27-KrgyisRA3hE36npKAVbN1W
    data-default-0.7.1.1-9j14EdJuVkFLjYlD1tloIt directory-1.3.6.0
    exceptions-0.10.4 filepath-1.4.2.1
    http-client-tls-0.3.5.3-LE2dTuRbsucFMao5SNupTA
    http-conduit-2.3.7.3-J65n7sSCocaImIiMWgvcUO
    http-types-0.12.3-53LE6EPnjaYL88m7GHuG2H
    lifted-base-0.2.3.12-32Je5waQHZkEwMmV5pIAvq
    memory-0.15.0-EuehB4FMe9b5ts9dSjTFQ5
    monad-control-1.0.2.3-Zolpha2nzyCWjP4MLl5a6 mtl-2.2.2
    network-3.1.1.1-CK9iofx0d8BBZLerEfDW1e
    network-bsd-2.8.1.0-9VdQYYkiaFR7vrQXuQSXuG
    old-locale-1.0.0.7-He1fhgasqBf2zFT9zlaLle
    resourcet-1.2.4.1-BfFxYNA42v4HhhW9DWi0Jk
    safe-0.3.19-CK0lfIX5mWD7fu30IXX07t
    scientific-0.3.6.2-KV9qEzQmSjuErx2uTg1kor
    tagged-0.8.6-6GC8EUw1ctH7ZAzzvpqZ7j text-1.2.3.2 time-1.9.3
    transformers-0.5.6.2
    unordered-containers-0.2.11.0-Gy9Rkzl4w678AYU9aLwMbs
    utf8-string-1.0.1.1-L5P9SR8YxIu1NqwMrJwV7a
    vector-0.12.1.2-2820kU4E8Rq2FpOG9Xf2aE
    xml-conduit-1.9.0.0-GHnC0xwHQJFV5kVdYmSnA

haddock-interfaces:   /usr/share/doc/haskell-aws/html/aws.haddock
haddock-html:         /usr/share/doc/haskell-aws/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
